Struct ZwpTabletPadStripV2
pub struct ZwpTabletPadStripV2 { /* private fields */ }wayland and Linux only.Expand description
pad strip
A linear interaction area, such as the strips found in Wacom Cintiq models.
Events on a strip are logically grouped by the zwp_tablet_pad_strip_v2.frame event.
See also the Event enum for this interface.
Implementations
impl ZwpTabletPadStripV2
impl ZwpTabletPadStripV2
pub fn set_feedback(&self, description: String, serial: u32)
pub fn set_feedback(&self, description: String, serial: u32)
set compositor feedback
Requests the compositor to use the provided feedback string associated with this strip. This request should be issued immediately after a zwp_tablet_pad_group_v2.mode_switch event from the corresponding group is received, or whenever the strip is mapped to a different action. See zwp_tablet_pad_group_v2.mode_switch for more details.
Clients are encouraged to provide context-aware descriptions for the actions associated with the strip, and compositors may use this information to offer visual feedback about the button layout (eg. on-screen displays).
The provided string ‘description’ is a UTF-8 encoded string to be associated with this ring, and is considered user-visible; general internationalization rules apply.
The serial argument will be that of the last zwp_tablet_pad_group_v2.mode_switch event received for the group of this strip. Requests providing other serials than the most recent one will be ignored.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the strip object
This destroys the client’s resource for this strip object.